##' High Level Encryption Wrappers
##'
##' Encryption wrappers, using low-level support from sodium and openssl.
##'
##' It is _strongly_ recommended that you read _both_ vignettes before
##' attempting to use `cyphr`.
##'
##' - [introduction](https://docs.ropensci.org/cyphr/articles/cyphr.html);
##'   in R: `vignette("cyphr", package = "cyphr")`
##' - [data vignette](https://docs.ropensci.org/cyphr/articles/data.html);
##'   in R: `vignette("data", package = "cyphr")`
##'
##' @author Rich FitzJohn (rich.fitzjohn@@gmail.com)
"_PACKAGE"
